SELECT
    a,
    b
FROM test TABLESAMPLE(50 PERCENT);

SELECT
    t.a,
    t.b
FROM test TABLESAMPLE(50 PERCENT) t;

SELECT
    t.a,
    t.b
FROM test TABLESAMPLE(50 PERCENT) AS t;

SELECT
    a,
    b
FROM test TABLESAMPLE(5 ROWS);

SELECT
    a,
    b
FROM test TABLESAMPLE(BUCKET 4 OUT OF 10);

SELECT
    test_1.a,
    test_1.b
FROM test_1 TABLESAMPLE(5 ROWS)
NATURAL JOIN test_2 TABLESAMPLE(BUCKET 4 OUT OF 10);

SELECT
    t1.a,
    t2.b
FROM test_1 TABLESAMPLE(5 ROWS) t1
NATURAL JOIN test_2 TABLESAMPLE(BUCKET 4 OUT OF 10) t2;

SELECT
    t1.a,
    t2.b
FROM test_1 TABLESAMPLE(5 ROWS) AS t1
NATURAL JOIN test_2 TABLESAMPLE(BUCKET 4 OUT OF 10) AS t2;
